/*  GFC-Core: GTK+ Foundation Classes (Core Library)
 *  Copyright (C) 2002-2004 The GFC Development Team.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/// @file gfc/gfccore.hh
/// @brief The main GFC-Core header file.
///
/// This header file includes all the GFC-Core header files and the compile-time
/// GFC-Core version numbers. You can safely include this header file only, with
/// minimal extra overhead, because each header file uses include guards to prevent
/// multiple inclusions.

/// @defgroup gfc_group The GFC Namespace
/// @namespace GFC
/// @brief The primary namespace for the GTK+ Foundation Classes.

/// @defgroup i18n_group The Internationalization Namespace
/// @namespace GFC::i18n
/// @ingroup gfc_group
/// @brief The internationalization and localization namespace.
///
/// Provides a C++ interface to GNU gettext for
/// Internationalization and Localization support.

/// @defgroup g_group The G Namespace
/// @namespace GFC::G
/// @ingroup gfc_group
/// @brief The C++ framework for the GObject and GLib libraries.
///
/// Implements the object API that provides the base classes for the
/// entire GFC library. Also wraps several of GLIB utility classes.

#ifndef GFC_CORE_HH
#define GFC_CORE_HH

/// Compile time major version macro.
#define GFC_CORE_MAJOR_VERSION (2)

/// Compile time minor version macro.
#define GFC_CORE_MINOR_VERSION (3)

/// Compile time micro version macro.
#define GFC_CORE_MICRO_VERSION (1)

#include <gfc/i18n.hh>
#include <gfc/glib/g.hh>

/// @name Library Version
/// @{

extern const unsigned int gfc_core_major_version;
///< Major version number.

extern const unsigned int gfc_core_minor_version;
///< Minor version number.

extern const unsigned int gfc_core_micro_version;
///< Micro version number.

bool gfc_core_check_version(int major, int minor, int micro);
///< Check whether an GFC-Core version equal to or greater than major.minor.micro is present.

/// @}

#endif // GFC_CORE_HH

